/*
	FontManager.h
	Application Kit, Release 2.0
	Copyright (c) 1988, 1989, 1990, NeXT, Inc.  All rights reserved. 
*/

#import <Foundation/NSObject.h>
#import "NSGraphics.h"

typedef unsigned int NSFontTraitMask;

/*
 * Font Traits
 *
 * This list should be kept small since the more traits that are assigned
 * to a given font, the harder it will be to map it to some other family.
 * Some traits are mutually exclusive such as NX_EXPANDED and NX_CONDENSED.
 */

#define NSItalicFontMask		0x00000001
#define NSBoldFontMask			0x00000002
#define NSUnboldFontMask		0x00000004
#define NSNonStandardCharacterSetFontMask	0x00000008
#define NSNarrowFontMask		0x00000010
#define NSExpandedFontMask		0x00000020
#define NSCondensedFontMask		0x00000040
#define NSSmallCapsFontMask		0x00000080
#define NSPosterFontMask		0x00000100
#define NSCompressedFontMask		0x00000200
#define NSUnitalicFontMask 		0x01000000	/* historical */

/* whatToDo values */

#define NSNoFontChangeAction		0
#define NSViaPanelFontAction		1
#define NSAddTraitFontAction		2
#define NSSizeUpFontAction		3
#define NSSizeDownFontAction		4
#define NSHeavierFontAction		5
#define NSLighterFontAction		6
#define NSRemoveTraitFontAction		7

#define NSAddTraitFontAction		2	/* historical */

@interface NSFontManager : NSObject
{
    id                  panel;
    id                  menu;
    SEL                 action;
    int                 whatToDo;
    NSFontTraitMask     traitToChange;
    id                  selFont;
    struct _fmFlags {
	unsigned int        multipleFont:1;
	unsigned int        disabled:1;
	unsigned int        _RESERVED:14;
    }                   fmFlags;
    unsigned short      _lastPos;
    id		        delegate;
    unsigned int        _reservedFMint2;
    unsigned int        _reservedFMint3;
    unsigned int        _reservedFMint4;
}

+ setFontPanelFactory:factoryId;
+ setFontManagerFactory:factoryId;
+ sharedFontManager;

- (BOOL)isMultiple;
- selFont;
- setSelFont:fontObj isMultiple:(BOOL)flag;
- convertFont:fontObj;
- getFontMenu:(BOOL)create;
- getFontPanel:(BOOL)create;
- findFont:(NSString *)family traits:(NSFontTraitMask)traits weight:(int)weight size:(float)size;
- getFamily:(const char **)family traits:(NSFontTraitMask *)traits weight:(int *)weight size:(float *)size ofFont:fontObj;
- (char **)availableFonts;
- convert:fontObj toSize:(float)size;
- convert:fontObj toFace:(NSString *)typeface;
- convert:fontObj toFamily:(NSString *)family;
- convert:fontObj toHaveTrait:(NSFontTraitMask)trait;
- convert:fontObj toNotHaveTrait:(NSFontTraitMask)trait;
- convertWeight:(BOOL)upFlag of:fontObj;
- addFontTrait:sender;
- removeFontTrait:sender;
- modifyFont:sender;
- orderFrontFontPanel:sender;
- modifyFontViaPanel:sender;
- (BOOL)isEnabled;
- setEnabled:(BOOL)flag;
- (SEL)action;
- setAction:(SEL)aSelector;
- finishUnarchiving;
- sendAction;
- setDelegate:anObject;
- delegate;

@end

@interface NSObject(FontManagerDelegate)
- (BOOL)fontManager:sender willIncludeFont:(NSString *)fontName;
@end
