/*
	NXImage.h
	Application Kit, Release 2.0
	Copyright (c) 1988, 1989, 1990, NeXT, Inc.  All rights reserved. 
*/

#import <Foundation/NSObject.h>
#import "color.h"
#import "NSImageRep.h"
#import "NSPasteboard.h"
#import <objc/List.h>
#import <objc/zone.h>
#import "NSGraphics.h"

@interface NSImage : NSObject
{
    char               *name;
    NSSize              _size;
    struct __imageFlags {
#ifdef __BIG_ENDIAN__
	unsigned int        scalable:1;
	unsigned int        dataRetained:1;
	unsigned int        flipDraw:1;
	unsigned int        uniqueWindow:1;
	unsigned int        uniqueWasExplicitlySet:1;
	unsigned int        sizeWasExplicitlySet:1;
	unsigned int        builtIn:1;
	unsigned int        needsToExpand:1;
	unsigned int        useEPSOnResolutionMismatch:1;
	unsigned int        colorMatchPreferred:1;
	unsigned int        multipleResolutionMatching:1;
	unsigned int        dontFreeName:1;
	unsigned int        subImage:1;
	unsigned int	    aSynch:1;
	unsigned int	    archiveByName:1;
	unsigned int	    unboundedCacheDepth:1;
#else
	unsigned int        unboundedCacheDepth:1;
	unsigned int        archiveByName:1;
	unsigned int        aSynch:1;
	unsigned int        subImage:1;
	unsigned int        dontFreeName:1;
	unsigned int        multipleResolutionMatching:1;
	unsigned int        colorMatchPreferred:1;
	unsigned int        useEPSOnResolutionMismatch:1;
	unsigned int        needsToExpand:1;
	unsigned int        builtIn:1;
	unsigned int        sizeWasExplicitlySet:1;
	unsigned int        uniqueWasExplicitlySet:1;
	unsigned int        uniqueWindow:1;
	unsigned int        flipDraw:1;
	unsigned int        dataRetained:1;
	unsigned int        scalable:1;
#endif
    }                   _flags;
    short		_reservedShort;
    void               *_reps;
    List               *_repList;
    NXColor            *_color;
    int			_reservedInt;
}

+ findImageNamed:(NSString *)name;

- init;
- initSize:(NSSize)aSize;
- initFromFile:(NSString *)fileName;
- initFromSection:(NSString *)fileName;
- initFromStream:(NXStream *)stream;
- initFromPasteboard:(NSPasteboard *)pasteboard;
- initFromImage:(NSImage *)image rect:(NSRect)rect;

- getImage:(NSImage **)image rect:(NSRect *)rect;
- setSize:(NSSize)aSize;
- (NSSize)size;
- (void)dealloc;
- copyFromZone:(NSZone *)zone;
- (BOOL)setName:(NSString *)string;
- (NSString *)name;
- setFlipped:(BOOL)flag;
- (BOOL)isFlipped;
- setScalable:(BOOL)flag;
- (BOOL)isScalable;
- setDataRetained:(BOOL)flag;
- (BOOL)isDataRetained;
- setUnique:(BOOL)flag;
- (BOOL)isUnique;
- setCacheDepthBounded:(BOOL)flag;
- (BOOL)isCacheDepthBounded;
- setBackgroundColor:(NXColor)aColor;
- (NXColor)backgroundColor;
- setEPSUsedOnResolutionMismatch:(BOOL)flag;
- (BOOL)isEPSUsedOnResolutionMismatch;
- setColorMatchPreferred:(BOOL)flag;
- (BOOL)isColorMatchPreferred;
- setMatchedOnMultipleResolution:(BOOL)flag;
- (BOOL)isMatchedOnMultipleResolution;
- dissolve:(float)delta toPoint:(NSPoint)point;
- dissolve:(float)delta fromRect:(NSRect)rect toPoint:(NSPoint)point;
- composite:(int)op toPoint:(NSPoint)point;
- composite:(int)op fromRect:(NSRect)rect toPoint:(NSPoint)point;
- (BOOL)drawRepresentation:(NSImageRep *)imageRep inRect:(NSRect)rect;
- recache;
- writeTIFF:(NXStream *)stream;
- writeTIFF:(NXStream *)stream allRepresentations:(BOOL)flag;
- writeTIFF:(NXStream *)stream allRepresentations:(BOOL)flag usingCompression:(int)compression andFactor:(float)aFloat;
- write:(NXTypedStream *)stream;
- read:(NXTypedStream *)stream;
- finishUnarchiving;
- (BOOL)loadFromStream:(NXStream *)stream;
- (BOOL)loadFromFile:(NSString *)fileName;
- (BOOL)useFromFile:(NSString *)fileName;
- (BOOL)useFromSection:(NSString *)fileName;
- (BOOL)useDrawMethod:(SEL)drawMethod inObject:anObject;
- (BOOL)useRepresentation:(NSImageRep *)imageRepresentation;
- (BOOL)useCacheWithDepth:(NSWindowDepth)depth;
- removeRepresentation:(NSImageRep *)imageRepresentation;
- (BOOL)lockFocus;
- (BOOL)lockFocusOn:(NSImageRep *)imageRepresentation;
- unlockFocus;
- (NSImageRep *)lastRepresentation;
- (NSImageRep *)bestRepresentation;
- (NSArray *)representationList;
- setDelegate:(id)anObject;
- delegate;


+ (void)registerImageRep:imageRepClass;
+ (void)unregisterImageRep:imageRepClass;
+ (Class)imageRepForFileType:(NSString *)type;
+ (Class)imageRepForPasteboardType:(NSString *)type;
+ (Class)imageRepForStream:(NXStream *)stream;
+ (NSArray *)imageUnfilteredFileTypes;
+ (NSArray *)imageFileTypes;
+ (NSArray *)imageUnfilteredPasteboardTypes;
+ (NSArray *)imagePasteboardTypes;
+ (BOOL)canInitFromPasteboard:(NSPasteboard *)pasteboard;

@end

@interface NSObject(NXImageDelegate)
- (NSImage *)imageDidNotDraw:sender inRect:(NSRect)aRect;
@end
