/*
	Matrix.h
	Application Kit, Release 2.0
	Copyright (c) 1988, 1989, 1990, NeXT, Inc.  All rights reserved. 
*/

#import "NSControl.h"
#import "color.h"

/* Matrix Constants */

typedef enum _NSMatrixMode {
    NSRadioModeMatrix			= 0,
    NSHighlightModeMatrix		= 1,
    NSListModeMatrix			= 2,
    NSTrackModeMatrix			= 3
} NSMatrixMode;

@interface NSMatrix : NSControl
{
    id                  cellList;
    id                  target;
    SEL                 action;
    id                  selectedCell;
    int                 selectedRow;
    int                 selectedCol;
    int                 numRows;
    int                 numCols;
    NSSize              cellSize;
    NSSize              intercell;
    float               backgroundGray;
    float               cellBackgroundGray;
    id                  font;
    id                  protoCell;
    id                  cellClass;
    id                  nextText;
    id                  previousText;
    SEL                 doubleAction;
    SEL                 errorAction;
    id                  textDelegate;
    struct _mFlags {
#ifdef __BIG_ENDIAN__
	unsigned int        highlightMode:1;
	unsigned int        radioMode:1;
	unsigned int        listMode:1;
	unsigned int        allowEmptySel:1;
	unsigned int        autoscroll:1;
	unsigned int        reaction:1;
	unsigned int        selectionByRect:1;
	unsigned int        _RESERVED:7;
	unsigned int        _autosizeCells:1;
	unsigned int        _drawingAncestor:1;
#else
	unsigned int        _drawingAncestor:1;
	unsigned int        _autosizeCells:1;
	unsigned int        _RESERVED:7;
	unsigned int        selectionByRect:1;
	unsigned int        reaction:1;
	unsigned int        autoscroll:1;
	unsigned int        allowEmptySel:1;
	unsigned int        listMode:1;
	unsigned int        radioMode:1;
	unsigned int        highlightMode:1;
#endif
    }                   mFlags;
    unsigned short      _reservedMshort1;
    unsigned int        _reservedMint1;
    void	        *_private;
}

+ initialize;
+ setCellClass:factoryId;

- initFrame:(NSRect)frameRect;
- initFrame:(NSRect)frameRect mode:(int)aMode prototype:aCell numRows:(int)rowsHigh numCols:(int)colsWide;
- initFrame:(NSRect)frameRect mode:(int)aMode cellClass:factoryId numRows:(int)rowsHigh numCols:(int)colsWide;

- (void)dealloc;
- setCellClass:factoryId;
- prototype;
- setPrototype:aCell;
- makeCellAt:(int)row :(int)col;
- (NSMatrixMode)mode;
- setMode:(NSMatrixMode)aMode;
- setEmptySelectionEnabled:(BOOL)flag;
- (BOOL)isEmptySelectionEnabled;
- sendAction:(SEL)aSelector to:anObject forAllCells:(BOOL)flag;
- cellList;
- selectedCell;
- getSelectedCells:(List *)aList;
- (int)selectedRow;
- (int)selectedCol;
- setSelectionByRect:(BOOL)flag;
- (BOOL)isSelectionByRect;
- setSelectionFrom:(int)startPos to:(int)endPos anchor:(int)anchorPos lit:(BOOL)lit;
- clearSelectedCell;
- selectCellAt:(int)row :(int)col;
- selectAll:sender;
- selectCell:aCell;
- selectCellWithTag:(int)anInt;
- (NSSize)cellSize;
- setCellSize:(NSSize)aSize;
- (NSSize)intercell;
- setIntercell:(NSSize)aSize;
- setEnabled:(BOOL)flag;
- setScrollable:(BOOL)flag;
- font;
- setFont:fontObj;
- (float)backgroundGray;
- setBackgroundGray:(float)value;
- setBackgroundColor:(NXColor)color;
- (NXColor)backgroundColor;
- setBackgroundTransparent:(BOOL)flag;
- (BOOL)isBackgroundTransparent;
- setCellBackgroundColor:(NXColor)color;
- (NXColor)cellBackgroundColor;
- setCellBackgroundTransparent:(BOOL)flag;
- (BOOL)isCellBackgroundTransparent;
- (float)cellBackgroundGray;
- setCellBackgroundGray:(float)value;
- setState:(int)value at:(int)row :(int)col;
- setIcon:(NSString *)iconName at:(int)row :(int)col;
- setTitle:(NSString *)aString at:(int)row :(int)col;
- (int)cellCount;
- getNumRows:(int *)rowCount numCols:(int *)colCount;
- (int)numberOfRows;
- (int)numberOfColumns;
- cellAt:(int)row :(int)col;
- (NSRect)cellFrameAt:(int)row :(int)col;
- getRow:(int *)row andCol:(int *)col ofCell:aCell;
- getRow:(int *)row andCol:(int *)col forPoint:(NSPoint)aPoint;
- renewRows:(int)newRows cols:(int)newCols;
- putCell:newCell at:(int)row :(int)col;
- addRow;
- insertRowAt:(int)row;
- removeRowAt:(int)row andFree:(BOOL)flag;
- addCol;
- insertColAt:(int)col;
- removeColAt:(int)col andFree:(BOOL)flag;
- findCellWithTag:(int)anInt;
- setTag:(int)anInt at:(int)row :(int)col;
- target;
- setTarget:anObject;
- setTarget:anObject at:(int)row :(int)col;
- (SEL)action;
- setAction:(SEL)aSelector;
- (SEL)doubleAction;
- setDoubleAction:(SEL)aSelector;
- (SEL)errorAction;
- setErrorAction:(SEL)aSelector;
- setAction:(SEL)aSelector at:(int)row :(int)col;
- setTag:(int)anInt target:anObject action:(SEL)aSelector at:(int)row :(int)col;
- setAutosizeCells:(BOOL)flag;
- (BOOL)doesAutosizeCells;
- setFrameSize:(NSSize)_newSize;
- sizeToCells;
- sizeToFit;
- validateSize:(BOOL)flag;
- calcSize;
- drawCell:aCell;
- drawCellInside:aCell;
- drawCellAt:(int)row :(int)col;
- highlightCellAt:(int)row :(int)col lit:(BOOL)flag;
- drawRect:(NSRect)rect;
- display;
- setAutoscroll:(BOOL)flag;
- scrollCellToVisible:(int)row :(int)col;
- setReaction:(BOOL)flag;
- (int)mouseDownFlags;
- mouseDown:(NXEvent *)theEvent;
- (BOOL)performKeyEquivalent:(NXEvent *)theEvent;
- sendAction:(SEL)theAction to:theTarget;
- sendAction;
- sendDoubleAction;
- textDelegate;
- setTextDelegate:anObject;
- (BOOL)textWillEnd:textObject;
- (BOOL)textWillChange:textObject;
- textDidEnd:textObject endChar:(unsigned short)whyEnd;
- textDidChange:textObject;
- textDidGetKeys:textObject isEmpty:(BOOL)flag;
- selectText:sender;
- selectTextAt:(int)row :(int)col;
- setPreviousText:anObject;
- setNextText:anObject;
- (BOOL)acceptsFirstMouse;
- write:(NXTypedStream *)stream;
- read:(NXTypedStream *)stream;
- resetCursorRects;

@end

#ifdef KANJI
@interface NSMatrix(InputManager)
- setIMEnabled:(BOOL)flag;
@end

@interface NSMatrix(IMSupportDelegate)
- (BOOL)textUsesIM:sender;
@end
#endif
