

#import <Foundation/NSObject.h>
#import <sys/time.h>
#import "NSGraphics.h"

#define NSMaxCharactersInPrintKey (1024)		// Max num of chars in key.

typedef enum _NSPrinterTableStatus {
    NSPrinterTableOK			= (0),
    NSPrinterTableNotFound		= (1),
    NSPrinterTableError			= (2),
} NSPrinterTableStatus;


@interface NSPrinter:NSObject
{
    const char	*printerName;
    const char	*hostName;
    const char	*domainName;
    const char	*printerType;
    BOOL	_ignore;
    BOOL	_valid;
    int		_creationNum;
    void	*_nodes;
    struct timeval _previousValid;
    long	_niInstance;
    void	*_priv;
    void	*reserved[10];
}

+ (NSPrinter *)newForName:(NSString *)name;
+ (NSPrinter *)newForName:(NSString *)name host:(NSString *)host;
+ (NSPrinter *)newForName:(NSString *)name host:(NSString *)host domain:(NSString *)domain includeUnavailable:(BOOL)flag;
+ (NSPrinter *)newForType:(NSString *)type;
+ (NSArray *)printerTypes:(BOOL)types custom:(BOOL)custom;

- (NSString *)name;
- (NSString *)domain;
- (NSString *)host;
- (NSString *)type;
- (NSString *)note;
- (BOOL)isColor;
- (BOOL)acceptsBinary;
- (BOOL)isOutputStackInReverseOrder;
- (NSSize)pageSizeForPaper:(NSString *)paperName;
- (NSRect)imageRectForPaper:(NSString *)paperName;
- (int)languageLevel;
- (BOOL)isFontAvailable:(NSString *)faceName;
- (BOOL)isReallyAPrinter;
- (NSPrinterTableStatus)statusForTable:(NSString *)table;
- (BOOL)isValid;

- (BOOL)isKey:(NSString *)key inTable:(NSString *)table;
- (NSString *)stringForKey:(NSString *)key inTable:(NSString *)table;
- (NSSize)sizeForKey:(NSString *)key inTable:(NSString *)table;
- (NSRect)rectForKey:(NSString *)key inTable:(NSString *)table;
- (int)intForKey:(NSString *)key inTable:(NSString *)table;
- (float)floatForKey:(NSString *)key inTable:(NSString *)table;
- (BOOL)booleanForKey:(NSString *)key inTable:(NSString *)table;
- (void *)dataForKey:(NSString *)key inTable:(NSString *)table length:(int *)lenp;
- (NSArray *)stringListForKey:(NSString *)key inTable:(NSString *)table;

- init;
- (void)dealloc;


@end
