/*
	Scroller.h
	Application Kit, Release 2.0
	Copyright (c) 1988, 1989, 1990, NeXT, Inc.  All rights reserved. 
*/

#import "NSControl.h"

typedef enum _NSScrollArrowPosition {
    NSScrollerArrowsMaxEnd		= 0,
    NSScrollerArrowsMinEnd		= 1,
    NSScrollerArrowsNone		= 2
} NSScrollArrowPosition;

typedef enum _NSUsableScrollerParts {
    NSNoScrollerParts			= 0,
    NSOnlyScrollerArrows		= 1,
    NSAllScrollerParts			= 2
} NSUsableScrollerParts;

typedef enum _NSScrollerPart {
    NSScrollerNoPart			= 0,
    NSScrollerDecrementPage		= 1,
    NSScrollerKnob			= 2,
    NSScrollerIncrementPage		= 3,
    NSScrollerDecrementLine		= 4,
    NSScrollerIncrementLine		= 5,
    NSScrollerKnobSlot			= 6
} NSScrollerPart;


extern const float NSScrollerWidth;

@interface NSScroller : NSControl
{
    float               curValue;
    float               perCent;
    float             _knobSize;
    int                 hitPart;
    id                  target;
    SEL                 action;
    struct _sFlags {
#ifdef __BIG_ENDIAN__
	unsigned int        isHoriz:1;
	unsigned int        arrowsLoc:2;
	unsigned int        partsUsable:2;
	unsigned int        _fine:1;
	unsigned int        _RESERVED:6;
	unsigned int        _needsEnableFlush:1;
	unsigned int        _thumbing:1;
	unsigned int        _slotDrawn:1;
	unsigned int        _knobDrawn:1;
#else
	unsigned int        _knobDrawn:1;
	unsigned int        _slotDrawn:1;
	unsigned int        _thumbing:1;
	unsigned int        _needsEnableFlush:1;
	unsigned int        _RESERVED:6;
	unsigned int        _fine:1;
	unsigned int        partsUsable:2;
	unsigned int        arrowsLoc:2;
	unsigned int        isHoriz:1;
#endif
    }                   sFlags;
}

+ (float)scrollerWidth;

- initFrame:(NSRect)frameRect;
- drawParts;
- awake;
- (NSRect)rectForPart:(int)partCode;
- checkSpaceForParts;
- target;
- setTarget:anObject;
- (SEL)action;
- setAction:(SEL)aSelector;
- setFrameSize:(NSSize)_newSize;
- setArrowsPosition:(NSScrollArrowPosition)where;
- drawArrow:(BOOL)whichButton :(BOOL)flag;
- drawKnob;
- drawRect:(NSRect)rect;
- highlight:(BOOL)flag;
- (NSScrollerPart)testPart:(NSPoint)thePoint;
- trackKnob:(NXEvent *)theEvent;
- trackScrollButtons:(NXEvent *)theEvent;
- mouseDown:(NXEvent *)theEvent;
- (int)hitPart;
- (float)floatValue;
- setFloatValue:(float)aFloat :(float)percent;
- setFloatValue:(float)aFloat;
- (BOOL)acceptsFirstMouse;
- write:(NXTypedStream *)stream;
- read:(NXTypedStream *)stream;

@end
