#import <Foundation/NSObject.h>
#import <objc/List.h>
#import "readOnlyTextStream.h"

/*
The server just handles all the checking in and IAC and delegates the real work to its delegate.  A single server can handle more than one language.  Services is used to rendezvous applications with servers.  The format of a services descriptor for a spell-checker:

Spell Checker: NeXT
Language: French
Language: English
Executable: franglais.daemon
*/

@class NSString;

@interface NSSpellServer : NSObject
{
@private		/* these are private and are */
    id delegate;	/* subject to change in any future */
    id guesses;		/* release, so don't access them! */
    id spellServer;
    void *dictionaries;
    id realTextStream;
    id learnedDictionaries;
    id forgottenDictionaries;
    BOOL delegateLearnsWords;
    BOOL delegateForgetsWords;
    BOOL padBOOL1, padBOOL2;
    int caseSensitive;
    void *reserved;
}

- setDelegate:anObject;
- delegate;

/* Used to check in */

- (BOOL)registerLanguage:(NSString *)language byVendor:(NSString *)vendor;

/* Way to query user's private dictionary(ies). */

- (BOOL)isInUserDictionary:(NSString *)word caseSensitive:(BOOL)flag;

/* Call back used inside implementations of suggestGuessesForWord:inLanguage:. */

- addGuess:(const char *)guess;

/* Waits for spell-check request to come in. */

- run;

@end

/*
This is the protocol the object in the server that does the real work actually must respond to.  The first method checks spelling and the second suggests proper corrections.  The second (guessing) method is optional.

The argument wordCount is an out parameter.  It should return the number of words found in the document from startPosition until the misspelled word was found (or the end of the stream)  If your spell server can't count words (though it is hard to imagine why that might be), return -1 in wordCount.  countOnly of YES means forget about checking the spelling of words, just count them until you get to the end of the stream.
*/

@interface NSObject(NXSpellServerDelegate)

- (BOOL)spellServer:(NSSpellServer *)sender findMisspelledWord:(int *)start length:(int *)length inLanguage:(NSString *)language inTextStream:(id <NXReadOnlyTextStream>)textStream startingAt:(int)startPosition wordCount:(int *)wordCount countOnly:(BOOL)countOnly;

- (void)spellServer:(NSSpellServer *)sender suggestGuessesForWord:(NSString *)word inLanguage:(NSString *)language;

- (void)spellServer:(NSSpellServer *)sender didLearnWord:(NSString *)word inLanguage:(NSString *)language;
- (void)spellServer:(NSSpellServer *)sender didForgetWord:(NSString *)word inLanguage:(NSString *)language;

@end
