#import <Foundation/NSObject.h>
#import <Foundation/NSGeometry.h>
#import <objc/hashtable.h>

@class NSImage, NSView;

@protocol NXWorkspaceRequestProtocol

- (BOOL)openFile:(NSString *)fullPath;
- (BOOL)openFile:(NSString *)fullPath withApplication:(NSString *)appName;
- (BOOL)openFile:(NSString *)fullPath withApplication:(NSString *)appName andDeactivate:(BOOL)flag;

- (BOOL)openTempFile:(NSString *)fullPath;

- (BOOL)openFile:(NSString *)fullPath fromImage:(NSImage *)anImage at:(NSPoint)point inView:(NSView *)aView;

- (BOOL)launchApplication:(NSString *)appName;
- (BOOL)launchApplication:(NSString *)appName showTile:(BOOL)showTile autolaunch:(BOOL)autolaunch;
- (NSString *)getFullPathForApplication:(NSString *)appName;

- (BOOL)findString:(NSString *)aString inFile:(NSString *)fullPath;
- (BOOL)selectFile:(NSString *)fullPath inFileViewerRootedAt:(NSString *)rootFullpath;

- (void)findApplications;

- (void)fileSystemChanged;
- (BOOL)didFileSystemChange;
- (void)defaultsChanged;
- (BOOL)didDefaultsChange;

/* Return values for type in getInfoForFile: */

extern NSString *NSPlainFileType, *NSDirectoryFileType, *NSApplicationFileType;
extern NSString *NSFilesystemFileType, *NSShellCommandFileType;

- (BOOL)getInfoForFile:(NSString *)fullPath application:(NSString **)appName type:(NSString **)type;

- (NSImage *)getIconForFile:(NSString *)fullPath;

- (BOOL)getInfoForFileSystemAt:(NSString *)fullPath isRemovable:(BOOL *)removableFlag isWritable:(BOOL *)writableFlag isUnmountable:(BOOL *)unmountableFlag description:(char **)description type:(char **)fileSystemType;

#define NSWorkspaceMoveOperation @"move"
#define NSWorkspaceCopyOperation @"copy"
#define NSWorkspaceLinkOperation @"link"
#define NSWorkspaceCompressOperation @"compress"
#define NSWorkspaceDecompressOperation @"decompress"
#define NSWorkspaceEncryptOperation @"encrypt"
#define NSWorkspaceDecryptOperation @"decrypt"
#define NSWorkspaceDestroyOperation @"destroy"
#define NSWorkspaceRecycleOperation @"recycle"
#define NSWorkspaceDuplicateOperation @"duplicate"

- (int)performFileOperation:(NSString *)operation source:(NSString *)source destination:(NSString *)destination files:(NSString *)files options:(NSString *)options;

- (BOOL)unmountAndEjectDeviceAt:(NSString *)path;
- (int)extendPowerOffBy:(int)requested;

- (void)slideImage:(NSImage *)image from:(NSPoint)fromPoint to:(NSPoint)toPoint;

- (void)hideOtherApplications;

- (void)beginListeningForDeviceStatusChanges;
- (void)endListeningForDeviceStatusChanges;

- (void)beginListeningForApplicationStatusChanges;
- (void)endListeningForApplicationStatusChanges;

- (BOOL)getMountedRemovableMedia:(char **)mountedList;
- (BOOL)mountNewRemovableMedia:(char **)newlyMountedList;
- (void)checkForRemovableMedia;

@end
